@@ -3,14 +3,13 @@
 # Crypt::HashCash::Client - Client for HashCash digital cash
 # Copyright (c) 2001-2017 Ashish Gulhati <crypt-hashcash at hash.neo.tc>
 #
-# $Id: lib/Crypt/HashCash/Client.pm v1.117 Sat Jun 10 10:50:47 PDT 2017 $
+# $Id: lib/Crypt/HashCash/Client.pm v1.118 Sat Jun 10 13:59:10 PDT 2017 $
 
 package Crypt::HashCash::Client;
 
 use warnings;
 use strict;
 
-use Wx qw (:everything);
 use Crypt::Random qw(makerandom);
 use Bytes::Random::Secure;
 use Crypt::RSA::Blind;
@@ -18,14 +17,13 @@ use Crypt::ECDSA::Blind;
 use Crypt::HashCash::Coin;
 use Crypt::HashCash::CoinRequest;
 use Crypt::CBC;
-use IO::Socket::INET;
 use Persistence::Object::Simple;
 use Crypt::EECDH;
 use Crypt::HashCash qw (_dec _hex);
 use Compress::Zlib;
 use vars qw( $VERSION $AUTOLOAD );
 
-our ( $VERSION ) = '$Revision: 1.117 $' =~ /\s+([\d\.]+)/;
+our ( $VERSION ) = '$Revision: 1.118 $' =~ /\s+([\d\.]+)/;
 
 sub new {
   my $class = shift;
@@ -168,6 +166,7 @@ sub msgvault {          # Encrypt and send a message to the vault, decrypt and r
 
 sub _msgvault {
   my ($self, $msg) = @_;
+  require IO::Socket::INET;
   $self->_diag("MV:connecting\n");
   return unless (my $vault = IO::Socket::INET->new(PeerAddr => 'localhost:20203'));
   print $vault "$msg\n";
@@ -181,6 +180,8 @@ sub _msgvault {
 }
 
 sub _msgvault_offline {
+  require Wx;
+  import Wx qw(:everything);
   my ($self, $msg) = @_;
   my $qrfh; my $level; my $qr;
   my $info = "Copy message from below and send to vault,\nthen replace with vault's response.";
@@ -210,7 +211,7 @@ sub _msgvault_offline {
     $dialog->SetMaxSize([$width,$dialog_height+$qrheight+$fontheight*2+10]);
     my $st = Wx::StaticBitmap->new( $dialog, -1, $qr, [$qrpos,10] );
   }
-  if($dialog->ShowModal == wxID_CANCEL) {
+  if($dialog->ShowModal == wxID_CANCEL()) {
     return;
   }
   $dialog->GetValue();
@@ -256,8 +257,8 @@ Crypt::HashCash::Client - Client for HashCash digital cash
 
 =head1 VERSION
 
- $Revision: 1.117 $
- $Date: Sat Jun 10 10:50:47 PDT 2017 $
+ $Revision: 1.118 $
+ $Date: Sat Jun 10 13:59:10 PDT 2017 $
 
 =head1 SYNOPSIS
 
